@@ -4,6 +4,7 @@
 # This file is distributed under the BSD 3-Clause License.
 #
 from django.contrib.postgres.fields import jsonb
+from djangokit.forms.postgres import JSONField as FormJSONField
 from djangokit.utils.encoders import JSONEncoder
 
 
@@ -14,3 +15,9 @@ class JSONField(jsonb.JSONField):
         super(JSONField, self).__init__(*args, **kwargs)
         if not self.encoder:
             self.encoder = JSONEncoder
+
+    def formfield(self, **kwargs):
+        return super().formfield(**{
+            'form_class': FormJSONField,
+            **kwargs,
+        })
